import 'dart:io';

import 'package:consoledoctor_vanguard_http/src/vanguard_constants.dart';

class VanguardHttpClientConfig {

  String serverUrl;
  final String appIdentifier;
  final String appName;
  final String deviceID;
  final String deviceName;
  final String deviceModel;
  final String username;
  final bool kiosk;

  VanguardHttpClientConfig({required this.serverUrl, required this.appIdentifier, required this.appName, required this.deviceID, required this.deviceName, required this.deviceModel, this.username = 'Kiosk-User', this.kiosk = true});

  Map<String, dynamic> buildHeaders() {
    var headers = {
      VanguardHeaders.apiKey: VanguardConstants.apiSecret,
      VanguardHeaders.appName: appIdentifier,
      VanguardHeaders.serviceName: appName,
      VanguardHeaders.deviceID: deviceID,
      VanguardHeaders.platform: Platform.operatingSystem,
      VanguardHeaders.hostname: deviceName,
      VanguardHeaders.device: deviceModel,
      VanguardHeaders.username: username
    };

    if (kiosk) headers[VanguardHeaders.kiosk] = 'true';

    return headers;
  }

  String buildUrlParams() {
    var params = '?${VanguardUrlParams.appName}=$appIdentifier&${VanguardUrlParams.serviceName}=$appName&${VanguardUrlParams.deviceID}=$deviceID&${VanguardUrlParams.platform}=${Platform.operatingSystem}&${VanguardUrlParams.hostname}=$deviceName&${VanguardUrlParams.device}=$deviceModel&${VanguardUrlParams.username}=$username';
    if (kiosk) params += '&${VanguardUrlParams.kiosk}=true';

    return params;
  }
}